==> aws-java-sdk-gamelift-1.10.52-sources.jar: com/amazonaws/services/gamelift/AbstractAmazonGameLift.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.gamelift;

import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.*;

/**
 * Abstract implementation of {@code AmazonGameLift}. Convenient method forms
 * pass through to the corresponding overload that takes a request object, which
 * throws an {@code UnsupportedOperationException}.
 */
public class AbstractAmazonGameLift implements AmazonGameLift {

    protected AbstractAmazonGameLift() {
    }

    @Override
    public void setEndpoint(String endpoint) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void setRegion(com.amazonaws.regions.Region region) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateAliasResult createAlias(CreateAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateBuildResult createBuild(CreateBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateFleetResult createFleet(CreateFleetRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateGameSessionResult createGameSession(
            CreateGameSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreatePlayerSessionResult createPlayerSession(
            CreatePlayerSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreatePlayerSessionsResult createPlayerSessions(
            CreatePlayerSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteAlias(DeleteAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteBuild(DeleteBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteFleet(DeleteFleetRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeAliasResult describeAlias(DescribeAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeBuildResult describeBuild(DescribeBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeEC2InstanceLimitsResult describeEC2InstanceLimits(
            DescribeEC2InstanceLimitsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetAttributesResult describeFleetAttributes(
            DescribeFleetAttributesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetCapacityResult describeFleetCapacity(
            DescribeFleetCapacityRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetEventsResult describeFleetEvents(
            DescribeFleetEventsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetPortSettingsResult describeFleetPortSettings(
            DescribeFleetPortSettingsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetUtilizationResult describeFleetUtilization(
            DescribeFleetUtilizationRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeGameSessionsResult describeGameSessions(
            DescribeGameSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribePlayerSessionsResult describePlayerSessions(
            DescribePlayerSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public GetGameSessionLogUrlResult getGameSessionLogUrl(
            GetGameSessionLogUrlRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListAliasesResult listAliases(ListAliasesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListBuildsResult listBuilds(ListBuildsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListFleetsResult listFleets(ListFleetsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public RequestUploadCredentialsResult requestUploadCredentials(
            RequestUploadCredentialsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ResolveAliasResult resolveAlias(ResolveAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateAliasResult updateAlias(UpdateAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateBuildResult updateBuild(UpdateBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetAttributesResult updateFleetAttributes(
            UpdateFleetAttributesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetCapacityResult updateFleetCapacity(
            UpdateFleetCapacityRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetPortSettingsResult updateFleetPortSettings(
            UpdateFleetPortSettingsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateGameSessionResult updateGameSession(
            UpdateGameSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void shutdown() {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public com.amazonaws.ResponseMetadata getCachedResponseMetadata(
            com.amazonaws.AmazonWebServiceRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }
}

==> aws-java-sdk-gamelift-1.10.77-sources.jar: com/amazonaws/services/gamelift/AbstractAmazonGameLift.java <==
/*
 * Copyright 2010-2016 Amazon.com, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://aws.amazon.com/apache2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package com.amazonaws.services.gamelift;

import com.amazonaws.services.gamelift.model.*;
import com.amazonaws.*;

/**
 * Abstract implementation of {@code AmazonGameLift}. Convenient method forms
 * pass through to the corresponding overload that takes a request object, which
 * throws an {@code UnsupportedOperationException}.
 */
public class AbstractAmazonGameLift implements AmazonGameLift {

    protected AbstractAmazonGameLift() {
    }

    @Override
    public void setEndpoint(String endpoint) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void setRegion(com.amazonaws.regions.Region region) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateAliasResult createAlias(CreateAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateBuildResult createBuild(CreateBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateFleetResult createFleet(CreateFleetRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreateGameSessionResult createGameSession(
            CreateGameSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreatePlayerSessionResult createPlayerSession(
            CreatePlayerSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public CreatePlayerSessionsResult createPlayerSessions(
            CreatePlayerSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteAlias(DeleteAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteBuild(DeleteBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteFleet(DeleteFleetRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void deleteScalingPolicy(DeleteScalingPolicyRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeAliasResult describeAlias(DescribeAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeBuildResult describeBuild(DescribeBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeEC2InstanceLimitsResult describeEC2InstanceLimits(
            DescribeEC2InstanceLimitsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetAttributesResult describeFleetAttributes(
            DescribeFleetAttributesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetCapacityResult describeFleetCapacity(
            DescribeFleetCapacityRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetEventsResult describeFleetEvents(
            DescribeFleetEventsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetPortSettingsResult describeFleetPortSettings(
            DescribeFleetPortSettingsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeFleetUtilizationResult describeFleetUtilization(
            DescribeFleetUtilizationRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeGameSessionDetailsResult describeGameSessionDetails(
            DescribeGameSessionDetailsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeGameSessionsResult describeGameSessions(
            DescribeGameSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribePlayerSessionsResult describePlayerSessions(
            DescribePlayerSessionsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public DescribeScalingPoliciesResult describeScalingPolicies(
            DescribeScalingPoliciesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public GetGameSessionLogUrlResult getGameSessionLogUrl(
            GetGameSessionLogUrlRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListAliasesResult listAliases(ListAliasesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListBuildsResult listBuilds(ListBuildsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ListFleetsResult listFleets(ListFleetsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public PutScalingPolicyResult putScalingPolicy(
            PutScalingPolicyRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public RequestUploadCredentialsResult requestUploadCredentials(
            RequestUploadCredentialsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public ResolveAliasResult resolveAlias(ResolveAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateAliasResult updateAlias(UpdateAliasRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateBuildResult updateBuild(UpdateBuildRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetAttributesResult updateFleetAttributes(
            UpdateFleetAttributesRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetCapacityResult updateFleetCapacity(
            UpdateFleetCapacityRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateFleetPortSettingsResult updateFleetPortSettings(
            UpdateFleetPortSettingsRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public UpdateGameSessionResult updateGameSession(
            UpdateGameSessionRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public void shutdown() {
        throw new java.lang.UnsupportedOperationException();
    }

    @Override
    public com.amazonaws.ResponseMetadata getCachedResponseMetadata(
            com.amazonaws.AmazonWebServiceRequest request) {
        throw new java.lang.UnsupportedOperationException();
    }
}
